==> haskell-binary-orphans-0.1.8.0-68-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-binary-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-orphans
version: 0.1.8.0
id: binary-orphans-0.1.8.0-72L0cU0nTlH3RK3NhDXHPm
key: binary-orphans-0.1.8.0-72L0cU0nTlH3RK3NhDXHPm
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-orphans#readme
synopsis: Orphan instances for binary
description:
    `binary-orphans` defines orphan instances for types in some popular packages.
category: Web
abi: ed1cf56dbe13899e23fe42ec9f5baefd
exposed: True
exposed-modules:
    Data.Binary.Orphans
import-dirs: /usr/lib/ghc-8.6.2/site-local/binary-orphans-0.1.8.0
library-dirs: /usr/lib/ghc-8.6.2/site-local/binary-orphans-0.1.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/binary-orphans-0.1.8.0
hs-libraries: HSbinary-orphans-0.1.8.0-72L0cU0nTlH3RK3NhDXHPm
depends:
    aeson-1.4.2.0-GPa03mfYORkG452ywvZ9uU base-4.12.0.0 binary-0.8.6.0
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    scientific-0.3.6.2-9lkO4JSfZDD3N7SSlCrzCi
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB text-1.2.3.1
    text-binary-0.2.1.1-96KOTVBvNf07QHlQtp73j1 time-1.8.0.2
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
    vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
    vector-binary-instances-0.2.5.1-IQaUNlPskFJ1IdtNmjl3KM
haddock-interfaces: /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock
haddock-html: /usr/share/doc/haskell-binary-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-orphans-0.1.8.0-70-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-binary-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-orphans
version: 0.1.8.0
id: binary-orphans-0.1.8.0-JLuB9wM6EU9Cjmeqw7j5kB
key: binary-orphans-0.1.8.0-JLuB9wM6EU9Cjmeqw7j5kB
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-orphans#readme
synopsis: Orphan instances for binary
description:
    `binary-orphans` defines orphan instances for types in some popular packages.
category: Web
abi: 3e61d34fed7476bab4e9572783fdf1e2
exposed: True
exposed-modules:
    Data.Binary.Orphans
import-dirs: /usr/lib/ghc-8.6.3/site-local/binary-orphans-0.1.8.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/binary-orphans-0.1.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/binary-orphans-0.1.8.0
hs-libraries: HSbinary-orphans-0.1.8.0-JLuB9wM6EU9Cjmeqw7j5kB
depends:
    aeson-1.4.2.0-BdBVLho0lrWC4iPoef6lEw base-4.12.0.0 binary-0.8.6.0
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    scientific-0.3.6.2-9lkO4JSfZDD3N7SSlCrzCi
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB text-1.2.3.1
    text-binary-0.2.1.1-96KOTVBvNf07QHlQtp73j1 time-1.8.0.2
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
    vector-binary-instances-0.2.5.1-9v2Hs4Y2fvx4gqXXobe9KA
haddock-interfaces: /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock
haddock-html: /usr/share/doc/haskell-binary-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
